package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$"`0`````````````"`!0````!`8`2P````#0``0.T```````T`"``
M"``H`"``'P````8````T`8``-`&``#0```$````!``````0````$`````P``
M`30!@`$T`8`!-````!<````7````!`````$````!``````&````!@`````"<
MH```G*`````%``$```````$``/Z$`8'^A`&!_H0```*0```$$`````8``0``
M`````@``_Q`!@?\0`8'_$````.````#@````!@````0````$```!3`&``4P!
M@`%,````+````"P````$````!&1TY5```)/4`8"3U`&`D]0```#\````_```
M``0````$9'3E4@``_H0!@?Z$`8'^A````7P```%\````!`````$O=7-R+VQI
M8F5X96,O;&0N96QF7W-O```````'````!`````%.971"4T0``#N:R@`````$
M````!`````-085@``````````&$```!C```````````````K````"0``````
M````````,P````H````[`````````"H``````````0```$<```!;````````
M`!H```!&````!0```!@````/````%0```#X`````````5P`````````2````
M-P```%(``````````````%\```!A````*0````````!1````/P```%X```!6
M````0`````````!#````'0```#````!5````(0```#T``````````````$D`
M````````!P````````!B````5````$4````;`````@```&``````````60``
M```````3````*````$@````````````````````-````+0``````````````
M6@```"8````````````````````?````-`````````!*````!````$$`````
M````-@````````````````````````!$`````````#4```!-````7```````
M``!=````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````X`````````````````````````````````````
M```````````````>````'``````````D`````````"(````C````)P``````
M```#````"``````````7````%@```"\````4```````````````,````````
M`"X````L````,@```!D````````````````````E````````````````````
M/````"`````````````````````1```````````````Z````!@``````````
M`````````#D`````````3`````````!0```````````````X````3P``````
M``!+`````````$(````+`````````$X````0````4P```#$```!8````````
M``````````````````````")```````````2````````#```````````$@``
M`````S<!@@*4`````!```!L````4```````````2```````#/0&`'+@````0
M$@``"@```!P``````````!(````````B```````````2```````#3@&`*M@`
M```P$@``"@```"D``````````!(```````,!```````````2````````,0``
M````````$@```````VD!@#7````!)!(```H```!T```````````2````````
M.0&`3A``````$@```````W4!@@$4`````!```!D```!)```````````2````
M````6```````````$@```````%X``````````!(```````!E```````````2
M````````;P``````````$@```````'D!@%+``````!(```L```!_````````
M```2````````B```````````$@```````@4``````````!(```````".````
M```````2````````E0``````````$@```````R8``````````!(```````"C
M`8(!*`````$1```;```"L0``````````(@```````+```````````!(`````
M``-\`8`?U````$`2```*```#B0&`(!0```'8$@``"@```Y4!@"Q````'&!(`
M``H```"^```````````6````````T0``````````$@```````Q,`````````
M`!(```````#<```````````2````````Y0&"`2`````$$0``&@```.T`````
M`````!(```````+W```````````2````````^0``````````$@```````0``
M`````````!(```````.B`8!%Q````<@2```*```!$P&"`2P````@$0``&P``
M`24``````````!(```````$U```````````2```````!0P``````````$@``
M`````4@!@?Z8````$Q$``!(```%7```````````2```````#K0&"`1`````$
M$0``&0```68``````````!(```````%R```````````2```````!AP``````
M````$@```````9(!@$_0`````!(```````,X`8("E``````0```;```"H@``
M````````$@```````:4``````````!(```````/H`8`2P````!P2```*```!
MLP``````````$@```````;L``````````!(```````''```````````2````
M```!U```````````$@```````[<!@"'L```%W!(```H```':```````````2
M```````!Y0``````````$@```````\0!@$>,```!<!(```H```'V````````
M```2```````#S@&"`10`````$```&@```]H!@!R`````.!(```H```/B`8!*
MZ````HP2```*```!_0``````````$@```````HH``````````"(```````/G
M`8`2P````!P2```*```#[P&`',@```,,$@``"@```_P!@"L(```!.!(```H`
M``($```````````2```````$#@&`)\@```"0$@``"@```@T!@%"@`````!(`
M``````(>```````````2```````"<P``````````$@``````!!P!@"A8````
MG!(```H```(E```````````2```````"+@``````````$@```````C0`````
M`````!(```````+J```````````2```````".0``````````$@```````MT!
M@@$8````!!$``!H```)!```````````2```````#"```````````$@``````
M`D@``````````!(```````0D`8!%5````'`2```*```"3P&"`5````$($0``
M&P```M(!@@$,````!!$``!D```0G`8`2H``````2```)```$+0&`,U@```)H
M$@``"@```0P``````````!(```````)4```````````2```````#&@``````
M````$@````!L:6)P97)L+G-O`')E86QL;V,`;65M;6]V90!R;61I<@!S=')C
M:'(`<W1R;F-M<`!S=')R8VAR`&)O;W1?1'EN84QO861E<@!P97)L7V-O;G-T
M<G5C=`!A8F]R=`!U;FQI;FL`7U]L<W1A=#4P`'!E<FQ?9G)E90!?9FEN:0!?
M7W-T870U,`!?97AI=`!M96UC<'D`<&5R;%]D97-T<G5C=`!03%]D;U]U;F1U
M;7``4&5R;%]S=E]S971P=@!03%]C=7)R96YT7V-O;G1E>'0`<&5R;%]A;&QO
M8P!C;&]S961I<@!E;G9I<F]N`%]?;W!E;F1I<C,P`&UE;7-E=`!097)L7W-A
M9F5S>7-M86QL;V,`7U]S=&%C:U]C:&M?9W5A<F0`4&5R;%]G=E]F971C:'!V
M`%]?<W!R:6YT9E]C:&L`<F5A9`!03%]M96UO<GE?=W)A<`!097)L7W-Y<U]I
M;FET,P!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO8V]N=&5X=`!097)L7VYE
M=UA3`%!E<FQ?871F;W)K7W5N;&]C:P!097)L7W-Y<U]T97)M`%]?97)R;F\`
M4&5R;%]M9U]S970`7U]M96UC<'E?8VAK`&UK9&ER`'!E<FQ?<&%R<V4`4&5R
M;%]N97=84U]F;&%G<P!A8V-E<W,`9V5T<&ED`'9F<')I;G1F`%!E<FQ?871F
M;W)K7VQO8VL`;65M8VUP`'!E<FQ?<G5N`&QS965K`&]P96X`<W!R:6YT9@!G
M971U:60`<W1R;&5N`%]?<T8`<W1R8VUP`&QI8FTN<V\N,`!L:6)C<GEP="YS
M;RXQ`'-T<F1U<`!L:6)P=&AR96%D+G-O+C$`7U]D97)E9VES=&5R7V9R86UE
M7VEN9F\`<'1H<F5A9%]A=&9O<FL`7U]R96=I<W1E<E]F<F%M95]I;F9O`&QI
M8F,N<V\N,3(`7U]P<F]G;F%M90!?7W!S7W-T<FEN9W,`7U]G971P=W5I9#4P
M`%]?<WES8V%L;`!A=&5X:70`7VQI8F-?:6YI=`!S=')T;VL`7U]R96%D9&ER
M,S``7U]S=&%C:U]C:&M?9F%I;`!?7V5N9`!P87)?8W5R<F5N=%]E>&5C`&=E
M=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C;&5A;G5P`%]E9&%T80!P
M87)?8F%S96YA;64`<&%R7V1I<FYA;64`<&%R7VUK=&UP9&ER`'-H85]U<&1A
M=&4`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`7U]B<W-?<W1A
M<G0`>'-?:6YI=`!M86EN`%]?<W1A<G0`<&%R7V9I;F1P<F]G`'!A<E]S971U
M<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R7V1I90!S:&%?:6YI=`!84U])
M;G1E<FYA;'-?4$%27T)/3U0`+W5S<B]P:V<O;&EB+W!E<FPU+S4N-#`N,"]P
M;W=E<G!C+6YE=&)S9"UT:')E860M;75L=&DO0T]213HO=7-R+W!K9R]L:6(`
M``&!_O@``!T!``````&!_PP``$@!``````&!__```"))``````&!_I@``#`3
M``````&"`2@``!P3``````&"`2P``"P3``````&"`5```%P3``````&"````
M``$5``````&"``0```(5``````&"``@```05``````&"``P```85``````&"
M`!````<5``````&"`!0```D5``````&"`!@```H5``````&"`!P```L5````
M``&"`"````T5``````&"`"0```X5``````&"`"@``!`5``````&"`"P``!$5
M``````&"`#```!(5``````&"`#0``!,5``````&"`#@``!05``````&"`#P`
M`!85``````&"`$```!<5``````&"`$0``!@5``````&"`$@``!D5``````&"
M`$P``!H5``````&"`%```!L5``````&"`%0``!T5``````&"`%@``!X5````
M``&"`%P``",5``````&"`&```"05``````&"`&0``"45``````&"`&@``"<5
M``````&"`&P``"@5``````&"`'```"D5``````&"`'0``"H5``````&"`'@`
M`"T5``````&"`'P``"X5``````&"`(```"\5``````&"`(0``#$5``````&"
M`(@``#,5``````&"`(P``#05``````&"`)```#45``````&"`)0``#85````
M``&"`)@``#@5``````&"`)P``#D5``````&"`*```#L5``````&"`*0``#P5
M``````&"`*@``#T5``````&"`*P``#X5``````&"`+```$`5``````&"`+0`
M`$$5``````&"`+@``$,5``````&"`+P``$<5``````&"`,```$@5``````&"
M`,0``$P5``````&"`,@``$X5``````&"`,P``$\5``````&"`-```%`5````
M``&"`-0``%(5``````&"`-@``%,5``````&"`-P``%05``````&"`.```%45
M``````&"`.0``%85``````&"`.@``%@5``````&"`.P``%D5``````&"`/``
M`%H5``````&"`/0``&`5``````&"`/@``&$5``````&"`/P``&(5`````'P(
M`J:0`0`$E"'_\$@`-U$X(0`0@`$`!'P(`Z9.@``@0I\`!7UH`J8]JP`".:UN
M2'SC.WA]!$-X2``!390A_^!\"`*F0I\`!9/!`!A_R`*F/]X``I.!`!`[WFO(
MD`$`)(%>@`"#GH`$?`K@0$"``'0[G/__D^$`''^*X%"3H0`45YSPOCNJ__P[
M_``!<^D``4&"`!R!*@``?5U3>'TI`Z9.@`0A?Y_C>4&"`#"!/0`$.YT`!#O_
M__\[O0`(?2D#IDZ`!"&!/``$?2D#IDZ`!"$W____0(+_V(.A`!2#X0`<@`$`
M)(.!`!"#P0`8?`@#IC@A`"!.@``@E"'_X'P(`J9"GP`%D\$`&'_(`J8_W@`"
MDX$`$#O>:PR3X0`<@YZ`#(/^@`B0`0`D?!_@0$"``#B3H0`4B3\`!RP)`/A`
M@@!$@3\`"#O_``R#O__T?2D#IDZ`!"%\'^!`D'T``$&`_]B#H0`4@`$`)(.!
M`!"#P0`8?`@#IH/A`!PX(0`@3H``($@`.A&4(?_@?`@"ID*?``6380`,?)LC
M>9/!`!A_R`*F/]X``I`!`"2300`(.]YJ@).!`!"3H0`4D^$`'$&"`9"!.P``
M@/Z`%(%)``"#7H`8+`H``($;``B39P``D1H``$&"`5R!'H`<D4@``($I``")
M20``+`H``$&"`"`H"@`O.2D``4""_^R1*```B4D``"P*``!`@O_H+`,``$&"
M``A(`#DA2``\;8$^@"0L"0``08(!0(%>@"B#GH`L?`K@0$"``&0[G/__.ZK_
M_'^*X%!7G/"^._P``7/I``%!@@`<@2H``'U=4WA]*0.F3H`$(7^?XWE!@@`P
M@3T`!#N=``0[____.[T`"'TI`Z9.@`0A@3P`!'TI`Z9.@`0A-____T""_]B`
M?H`P2``XF8%>@#2#GH`X?`K@0$"``&0[G/__.ZK__'^*X%!7G/"^._P``7/I
M``%!@@`<@2H``'U=4WA]*0.F3H`$(7^?XWE!@@`P@3T`!#N=``0[____.[T`
M"'TI`Z9.@`0A@3P`!'TI`Z9.@`0A-____T""_]B`?H`\2``X(4O__-V`N@``
M@)L``(![``1(`#452``WJ8$^@!R!7H`@D4D``$O__M"`WH`0..``$SB@``(X
M8```.(``!$S&,8)(`#DM.&```4@`.'5+__V)2__^P)0A_]"3@0`@?'P;>9/A
M`"Q!@@#</2`!@I-A`!R#:0$@+!L``$&"`-"300`8?)HC>).A`"1_G>-XB3P`
M`"P)``!!@@#`*`D`/4&"`!"-/0`!+`D``$""__!_O.A0@_L``"P?``!!@@"D
M?`@"II/!`"B0`0`T?W[;>'^EZWA_A.-X?^/[>$@`-S4L`P``0((`$'T_Z*XL
M"0`]08(`/(?^``0L'P``0(+_U(`!`#2#00`8@V$`''P(`Z:#H0`D@\$`*'_C
M^WB#@0`@@^$`+#@A`#!.@``@?]OP4#N]``%_WA9P?__J%)/:``!+___`.^``
M`$O__]"#80`<.^```$O__\0[H```2___6(-!`!B#80`<@Z$`)$O__ZR4(?\P
MDZ$`Q'Q]&WF3X0#,/^`!@CO_`2R!/P``D2$`K#D@``!!@@`0B3T``"P)``!`
M@@`H@2$`K(%?``!]*5)Y.4```$""`52#H0#$@^$`S#@A`-!.@``@?`@"II/!
M`,B0`0#42``WC7Q^&WE!@@$4DT$`N#]``8"3@0#`.UI3+'_#\WA(`#F]+`,`
M`$&"`+")(P`-.X,`#34I_])`@@`0B3P``2P)``!!@O_8B2,`#34I_])!@@"P
M?Z/K>)-A`+Q(`#E1?'L;>'^#XWA(`#E%?'L:%#AC``)(`#E)?X;C>'^EZWA\
M?!MX?T33>$S&,8)(`#CQ.($`$'^#XWA(`#9%+`/__W^#XWA!@@`4@2$`&%4I
M!"8L"4``08(`>$@`-?5_@^-X2``UK7_#\WB#80"\2``Y$2P#``!`@O]8?\/S
M>$@`-J%_H^MX2``U.8`!`-2#00"X@X$`P'P(`Z:#P0#(2__^U(D\``$U*?_2
M0*+_3(D\``(L"0``08+_"$O__SR``0#4@\$`R'P(`Z9+__ZH2__^<4O__XQ\
M"`*FDT$`N)`!`-2380"\DX$`P)/!`,A(`#7AE"'_0'P(`J:3X0"\/^`!@CO_
M`2PX@0`0D\$`N($_``"1(0"L.2```)`!`,1\?AMX2``U/2P#``!`@@`X@2$`
M&%4I!"8H"4``08(`$&TJ__\L"J``0((`('_#\W@X@``"2``W'7QC`#148]E^
M2```"#A@``"!(0"L@5\``'TI4GDY0```0((`'(`!`,2#P0"X@^$`O'P(`Z8X
M(0#`3H``($@`-3V4(?^P?`@"II`!`%2380`\DX$`0).A`$0_H`&"D\$`2#N]
M`2R3X0!,?'\;>),A`#2!70``D4$`'#E```"300`XB20``&DI`#TA*0``?\0!
ME'_#\WA(`#=E.($`&'Q[&WA_X_MX3,8Q@DO__"E\?!MY08(!*$@`-T5\&QA`
M0($`^(,A`!@_0`&"5SD0.HD_``!_ZOMX+`D``$"B`!1(``&XC2H``2P)``!!
M@@`,*`D`/4""__!]7U!0.'L``H.:`2!\8U(42``W!2P#``!\?,DN08(`9(E?
M``"!(0`8@1H!("P*``!5*1`Z?0A(+IE(``!`H@`82```G(U?``$L"@``F4D`
M`4&"`(PH"@`]?0E#>#D(``%`@O_D.4``/3O>__^920``C5X``2P*``"=20`!
M0(+_]($A`!R!70``?2E2>3E```!`@@$D@`$`5(,A`#2#00`X?`@#IH-A`#R#
M@0!`@Z$`1(/!`$B#X0!,."$`4$Z``"`[WO__.YS__XU>``$L"@``G5P``4""
M__1+__^H?0E#>$O__X0_0`&"DN$`+),!`#""^@$@@3<``"P)``!!@@"L?NF[
M>#N```"%20`$?XCC>#N<``$L"@``0(+_\#D(``-5!!`Z/2`!@H%)`H0L"@``
M0((`4#E```%\@R-XD4D"A$@`-=5\>!MY08(`>%>9$#I^Y+MX?R7+>$@`,@V3
M&@$@.3P``3E```!5*1`Z?5A)+I.!`!B"X0`L@P$`,$O__EQ^X[MX2``QT2P#
M``"0>@$@?'@;>$&"`"Q7F1`Z2___Q#E```!+__Y@.(``"#N```!+__]TDN$`
M+),!`#!(`#+)@N$`+(,!`#!+__ZXE"'_X'P(`J8\P`&!/*`!@)/A`!P_X`&"
M.___])`!`"2#___\/(`!@'__$A0XQI.0@'\``#BE3A`XA%,T2``S?8`!`"0\
MX`&`@'\``#CG5A2#X0`</*`!@#R``8!\YCMX.*4S6#B$4U`Y````?`@#IC@A
M`"!(`#/4/2`!@I0A__`Y*?_T/,`!@8$I__P\H`&`?2D2%#R``8"`:0``.,:3
MD#BE3A`XA%,T."$`$$@`,PR4(?_P.&```#@A`!!.@``@E"'[$'V``"8]0`&`
M?`@"II+A!,P^X`&"DX$$X#KW`2R3X03L?'P;>'R?(W@X:E-H.($`')`!!/23
M803<@3<``)$A!+PY(```D8$$P$S&,8)+__D!?'L;>#B``"]_@^-X2``PF2P#
M``!!@@!8/&`!@'^$XW@X8U-T3,8Q@DO__$5_@^-X@2$$O(%7``!]*5)Y.4``
M`$""`EB``03T@8$$P(+A!,Q\"`.F@V$$W'V`@2"#@03@@^$$[#@A!/!.@``@
MDT$$V#]``8!_X_MX.UI3A$@`,RE_1--X2``Q82X;``!\?QMY08("`)*A!,0^
MH`&`DL$$R#K```"3`030/P`!@),A!-0_(`&`D\$$Z#JU4OR3H03D.QA2^#LY
M4XABUH``.Z```(D_```L"0``08(!/$&2`!A_Y/MX?V/;>$@`,UTL`P``08(`
M\'_C^WA(`#,M./\``3DC__]\?AMX?3]*%'U?&A1\'TA`0(``;'T'4%!Q"0`!
M08(`'(TJ__\L"0`O0((`2'P'4$";J@``08(`/%4)^'Y]*0.F2```()NJ__\Y
M2/__B2C__RP)`"]`@@`<FZC__T)``!2)*O__.0K__RP)`"]!@O_8?^/[>$@`
M,JU\?AMX?X/C>$@`,J%_P_(4.]X``2@>`_]!@0!@?^?[>'^)XWA_",-X?R;+
M>#B@!``X@```.&$`O$S&,8)(`#"=.($`(#AA`+Q(`"^1+`,``$""`!2!(0`H
M52D$)GP)L`!!@@!D?T33>#A@``!(`"_]?'\;>4""_N""H03$@L$$R(,!!-"#
M(034@T$$V(.A!.2#P03H2__^"$&2`!").P``-2G_TD&"`!`[P``!?K^K>$O_
M_U2).P`!+`D``$&"_ZA+___H.(```3AA`+Q(`##]+`,``$""_Y`\8`&`.($`
MO#AC4W1,QC&"2__Z"3AA`+Q(`#$Y@J$$Q(+!!,B#`030@R$$U(-!!-B#H03D
M@\$$Z$O__:2#00382__]A)*A!,22P03(DP$$T),A!-230038DZ$$Y)/!!.A(
M`"[QE"'_X'P(`J8X@``OD^$`''Q_&WB0`0`D2``N!2P#``!!@@`(.^,``8`!
M`"1_X_MX@^$`'#@A`"!\"`.F2``PL)0A^]"3H00D/Z`!@I/!!"A\?AMY.[T!
M+($]``"1(00<.2```$&"`0")/@``+`D``$&"`/1\"`*FD^$$+)`!!#1(`##M
M.*,``7Q_&W@H!00`08$!*).!!"`[@0`<?\3S>'^#XW@XP`0`2``OI3D___]]
M/$H4?!Q(0$"``%1__/H4.0$`'7TH^%`Y0```<2<``4""`,!5*?A^?2D#ID@`
M`""97___.^G__XD)__\L"``O0((`')E)__]"0``4B1___SD___\L"``O08+_
MV#B``"]_@^-X2``M"2P#``!!@@"D?`/@0$&!`(A_@^-X2``OP8.!!""!(00<
M@5T``'TI4GDY0```0((`N(`!!#2#X00L@Z$$)'P(`Z:#P00H."$$,$Z``""!
M(00<@5T``'TI4GDY0```0((`D(.A!"0\8`&`@\$$*#AC4OPX(00P2``O8(S_
M__\L!P`O0*+_='P?0$"97P``0(+_,$O__V0Y(```F2,``$O__W0X8```2___
M>($A!!R!70``?2E2>3E```!`@@`P@`$$-#Q@`8"#@00@.&-2_(/A!"Q\"`.F
M@Z$$)(/!!"@X(00P2``N]).!!"!(`"SM?`@"II.!!""0`00TD^$$+$@`+-F4
M(?_`?`@"II/A`#P_X`&"D\$`.#O_`2P_P`&`D`$`1),A`"0[WE.0DT$`*($_
M``"1(0`<.2```)-A`"R3@0`PDZ$`-#^@`8(X@0`8?\/S>$S&,8)+__/9+`,`
M`$&"`$R!00`8@1T!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``
ME4D`!$""__0X@0`8?\/S>$S&,8)+__.1+`,``$""_[P_P`&`/Z`!@CO>4YPX
M@0`8?\/S>$S&,8)+__-M+`,``$&"`$R!00`8@1T!(%5*$#I]*%(4@.D`!"P'
M``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`8?\/S>$S&,8)+__,E+`,`
M`$""_[P_P`&`/Z`!@CO>4Z0X@0`8?\/S>$S&,8)+__,!+`,``$&"`$R!00`8
M@1T!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X
M@0`8?\/S>$S&,8)+__*Y+`,``$""_[P_P`&`/Z`!@CO>4[`X@0`8?\/S>$S&
M,8)+__*5+`,``$&"`$R!00`8@1T!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_
MS(%)``@L"@``E4D`!$""__0X@0`8?\/S>$S&,8)+__)-+`,``$""_[P_P`&`
M/Z`!@CO>4[@X@0`8?\/S>$S&,8)+__(I+`,``$&"`$R!00`8@1T!(%5*$#I]
M*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`8?\/S>$S&
M,8)+__'A+`,``$""_[P_H`&`/X`!@CN]4\@X@0`8?Z/K>$S&,8)+__&]+`,`
M`$&"`$R!00`8@1P!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``
ME4D`!$""__0X@0`8?Z/K>$S&,8)+__%U+`,``$""_[P_H`&`/X`!@CN]4V@X
M@0`8?Z/K>$S&,8)+__%1+`,``$&"`$R!00`8@1P!(%5*$#I]*%(4@.D`!"P'
M``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`8?Z/K>$S&,8)+__$)+`,`
M`$""_[P_@`&`/V`!@CN<4]0X@0`8?X/C>$S&,8)+__#E+`,``$&"`$R!00`8
M@1L!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X
M@0`8?X/C>$S&,8)+__"=+`,``$""_[P_8`&`/T`!@CM[4^`X@0`8?V/;>$S&
M,8)+__!Y+`,``$&"`$R!00`8@1H!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_
MS(%)``@L"@``E4D`!$""__0X@0`8?V/;>$S&,8)+__`Q+`,``$""_[P_0`&`
M/R`!@CM:4^PX@0`8?T/3>$S&,8)+__`-+`,``$&"`$R!00`8@1D!(%5*$#I]
M*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``E4D`!$""__0X@0`8?T/3>$S&
M,8)+_^_%+`,``$""_[P_0`&`/R`!@CM:4W0X@0`8?T/3>$S&,8)+_^^A+`,`
M`$&"`$R!00`8@1D!(%5*$#I]*%(4@.D`!"P'``!\Z%$N0:+_S(%)``@L"@``
ME4D`!$""__0X@0`8?T/3>$S&,8)+_^]9+`,``$""_[P\8`&`.($`&#AC4_A,
MQC&"2__O/7QD&WE!@@`0?V/;>$S&,8)+__*9/&`!@#B!`!@X8U0,3,8Q@DO_
M[Q5\9!MY08(`%#Q@`8`X8U,`3,8Q@DO_\FT\8`&`.($`&#AC5"!,QC&"2__N
MZ7QD&WE!@@!@?Z/K>$S&,8)+__)%@2$`'(%?``!]*5)Y.4```$""`&R``0!$
M/(`!@(,A`"1_P_-X@T$`*#B$5$2#80`L?`@#IH.!`#"#H0`T@\$`.(/A`#PX
M(0!`3,8Q@DO_\?0\8`&`.($`&#AC5#!,QC&"2__N<7QD&WE!HO^8?X/C>$S&
M,8)+__'-2___B$@`)OV4(?_0/&`!@'P(`J8X8U/4D^$`+#_@`8([_P$L.($`
M&)`!`#2!/P``D2$`'#D@``!,QC&"2__N'2P#``!!@@!(B2,``#A@```L"0``
M08(`$&DI`#`P:?__?&-)$($A`!R!7P``?2E2>3E```!`@@`@@`$`-(/A`"PX
M(0`P?`@#IDZ``"`X8```2___U$@`)FV4(?^`?`@"II"!`!1\9!MXD`$`A)"A
M`!B0P0`<D.$`()$!`"21(0`HD4$`+$"&`"38(0`PV$$`.-AA`$#8@0!(V*$`
M4-C!`%C8X0!@V0$`:#T@`8(\8`&".2D!+#C```$XX```.0$`B#E!`!`X8P(`
M.*$`<)C!`'"8X0!Q@6D``)%A`'PY8```D0$`=)%!`'A(`">I.&``_T@`))$\
M`/_^?"P+>&``_[`](``!?"$!;GP(`J9A*0`<..```I+L_]R33/_H/N`!@I-L
M_^PZ]P$LDZS_]#B@``"0#``$.,```),,_^!\>AMXDRS_Y).,__"3S/_XD^S_
M_(%7``!]20DN.4```$@`)X4Q)/__?&,!U'Q[_G!]/=IX?[OH$%>]!#Y_O=IX
M?[OH$'][V1!_O4@0?WL9$"P;``!!@`$0/P```3^``8([P0`48Q@`"#N<`0`_
M(/__..```']EVWA_INMX?T/3>$@`)R4L`___08(`Z'\%PWA_Q/-X?T/3>$@`
M):TL`___08(`Z"@#``=`@0"D.&/_^'_^&A1\'_!`0*``%$@``)`[____?!_P
M0$&``(0XH``(?X3C>'_C^WA(`":=+`,``$""_^`Y(0`4?^GX4'_C_G!\G^@4
M?&/9%#T@``%A*0`<?4D(+H$W``!]2DIY.2```$""`(B!80``@`L`!(+K_]R#
M"__@?`@#IH,K_^2#2__H@VO_[(.+__"#J__T@\O_^(/K__Q]85MX3H``('^]
MR!1_>P'4+!O__T""_QA\'<@`0(+_$#A@__\X@/__2___C"P$__]`@O\8/&`!
M@#AC5$A,QC&"2__]F3Q@`8`X8U183,8Q@DO__8E(`"/ME"'_\'P(`J:0`0`4
M2``F/4@`)ADL`P``08(`"(!C``"``0`4."$`$'P(`Z9.@``@E"'_P'P(`J:3
MP0`X/\`!@).A`#0[WE1D/Z`!@I.!`#`[O0$L?'P;>#B!`!A_P_-XD^$`/($]
M``"1(0`<.2```)`!`$1,QC&"2__JR7Q_&WE!@@`0B3\``"P)``!`@@!$@2$`
M'(%=``!]*5)Y.4```$""`+R``0!$?X3C>(.A`#1_P_-X@X$`,'P(`Z:#P0`X
M@^$`/#@A`$!,QC&"2__MY'^#XWB380`L2``ED7Q[&WA_X_MX2``EA7Q[&A0X
M8P`"2``EB3S``8`\@`&`?^?[>'^%XW@XQE.$.(13B'Q_&WA,QC&"2``E)8$A
M`!R!70``?2E2>3E```!`@@`\@`$`1'_D^WB#80`L?\/S>(.!`#!\"`.F@Z$`
M-(/!`#B#X0`\."$`0$S&,8)+_^U8DV$`+$@`(HE(`"*%/2`!@90A_K`Y*9.0
M?`@"IH$)``R!20`4@,D`&(#I`!R1`0`@D4$`*($)`""!20`DDX$!0#^``8"3
MH0%$/Z`!@H"I`!`[G%-HD,$`.#N]`2R`R0`H@)T``)"!`1PX@```D.$`/#B!
M`!R`Z0`LD0$`0)%!`$2!"0`P@4D`-($I`#B380$\?'L;>'^#XWB3X0%,D`$!
M5)"A`"20P0!(D.$`3)$!`"R100`PD2$`-$S&,8)+_^DI?'\;>4&"`!")/P``
M+`D``$""`RB3`0$PDR$!-)-!`3B3P0%(2``D"4@`(^4L`P``08("E(/#```L
M'@``08("B'_#\WA(`"0)5&,(/#AC``%(`"0-B+X``'QY&W@L!0``08(`,#]`
M`8!_/\MX.UI4?'_C^WA_1--X3,8Q@D@`(Z&,O@`!._\``BP%``!`@O_D/&`!
M@#O!`#@X8U,`2```$(1^``0L`P``08(`0#B!`!Q,QC&"2__H<7Q_&WE!HO_D
MB3\``"P)``!!@O_82__K)2P#``!!@O_,?^/[>$@`(O%\?QMY0*(`7#O```!7
MR1`Z.2D!('TI"A2#Z?\`+!\``$&"`#Q7VA`Z.2$`('])TA2)/P``+`D``$&"
M`"1_X_MX.]X``4O_ZLTL`P``0((`_(?Z``0L'P``0(+_V#O@``!_X_MX/P`!
M@$@`(P4[&%+X?'X;>'\CRWA(`"+U?]X:%#O>!`1_P_-X2``B]3S@`8`\@`&`
M?RC+>'_E^WA_!L-X?'H;>#CG5(0XA%2,3,8Q@D@`(HU_0]-X.(`!P$@`(:$L
M`___08(`W#B!`%!_0]-X2``?K7Q_&WE!@@"$@+L``#R``8`\8`&"?T;3>#B$
M5-0X8P(`3,8Q@D@`'\4[P```@2$!'(%=``!]*5)Y.4```$""!$R``0%4?\/S
M>(,!`3"#(0$T?`@#IH-!`3B#P0%(@V$!/(.!`4"#H0%$@^$!3#@A`5!.@``@
M?^/[>$@`(:%\?QMY08+^N$O__PB!(0!852D$)BP)0`!`@O]T@R$`;$@`(=U\
M&1@`0(+_9($A`%B2P0$H52D%_I+A`2PL"0'`08(!((+!`2B"X0$L2___0$@`
M((V!(P``+`D`$4&"_QR#^P``2``@>8#C```\@`&`/&`!@G_E^WA_1M-X.(14
MF#AC`@`[P```3,8Q@D@`'N%+__\@.T```%=)$#HY*0$@?2D*%(!I_PPL`P``
M08(`F%=>$#HY(0`L._H``7_)\A1(```4A'X`!"P#``!!@@!X._\``3B!`!Q_
M^OMX3,8Q@DO_YA5\:1MY0:+_W(DI```L"0``08+_T$@`(*5\?AMY0(+]$$O_
M_Y1+__K=@2$!'(%=``!]*5)Y.4```$""`OR``0%4?^/[>(-A`3R#@0%`?`@#
MIH.A`42#X0%,."$!4$@`(%PX8``-/\`!@$@`(.$[WE1T?'D;>#B@`%-+__S8
M?\/S>$@`(,DX@0`<?'X;>#Q@`8`X8U4H3,8Q@DO_Y7E\9!MY08(!7(![``!+
M_^P9?'<;>4&"`4Q^X[MX2``@@2@#``-\>1MX0($`.#R``8`X8__\.(15,'QW
M&A1(`""!+`,``$""`!PH&0`$08(!\'\WRA2).?_[+`D`+T&"`>`_8`&`.($`
M'#M[4]1_8]MX3,8Q@DO_Y0$L`P``08(`[(DC```L"0``08(`X"@)`#!!@@#8
M/(`!@']CVW@XA%1$/V`!@$S&,8)+_^@].WM6%$@`'QT\@`&`?&<;>']HVW@X
MA%5<?P;#>']%TWA_P_-X/R`!@$S&,8)(`!^5.SE5;$@``$!(`!YY@2,``"P)
M`!%`@@!$2``>V3O_``%\9QMX?^C[>']IVWA_!L-X?T73>'\DRWA_P_-X3,8Q
M@D@`'U$X@`'`?\/S>$@`'F4L`___08+_M']#TWA(`!PE?\3S>'^#XWA,QC&"
M2__GG7_#\WA+__D5@L$!*(+A`2Q+__S4@OL``$O__K1^X[MX.(```$S&,8)(
M`![9?'D;>4&"_QA+__;1?'<;>7R6(WA!@/\(,,3_]CC@``!\MP'4?R/+>$@`
M'ITX@0#H.*``!G\CRWA(`!TM+`,`!D""`,2!00#H/2``0V$I04-\"D@`0(+^
MR*$A`.PL"4A%0(+^O##6_\XXX```?+<!U'\CRWA(`!Y1?R/+>#B!`/`XH``H
M2``<X3O@```L`P`H0((`=#T``8`\@`&`..$`\'\&PW@Y"%84.(153']%TWA_
MP_-XF^$!&$S&,8)(`!XY2__^_(-[``0L&P``0:+^'']CVWA(`!Y1*`,``T"A
M_@PX8__\/(`!@'Q[&A0XA%4X2``>52P#``!`HOWP?W?;>$O__>@\8`&`.&-5
M0$S&,8)+__4MDL$!*)+A`2Q(`!N)DL$!*)+A`2R3`0$PDR$!-)-!`3B3P0%(
M2``;;90A_\!\"`*F/&`!@)/A`#P_X`&".___]).!`#"0`0!$@3___)-A`"Q]
M*1(4DZ$`-#^``8*3P0`X.YP!+(%<``"100`<.4```#B!`!B!*0``.&-3N(E)
M`&2920!E3,8Q@DO_XF$L`P``08(`$(DC```L"0`Q08(!;$O_[AV#W__\/(`!
M@'_>$A0XA%6`@'X``#C```,XH``!2``;<7Q]&WE!@@`P@3T`##R@`8"`?@``
M.*55A(")``!(`!K1@3T`#(")``"!)``(=2D`0$""`6R#W__\/(`!@'_>$A0X
MA%6,@'X``#C```,XH``!2``;'7Q[&WE!@@`P/&`!@#B!`!@X8U-T3,8Q@DO_
MX;E\91MY08(!!($[``R`?@``@(D``$@`&FD_H`&".[T"A(/___P\@`&`?_\2
M%#B$59"#WP``.*```7_#\WA(`!L!/*`!@'QD&W@XI56H?\/S>$@`&BV!/P``
M.4```#Q@`8"920!E.($`&#AC4VA,QC&"2__A12P#``"0?0`(08(`:#B``<!(
M`!M)+`,`$4&"`!`Y(P`!*`D``4&!`*"!(0`<@5P``'TI4GDY0```0((`K(`!
M`$2#80`L@X$`,'P(`Z:#H0`T@\$`.(/A`#PX(0!`3H``((DC``$L"0``0:+^
ME$O__HR`?0`$2__V]2P#``"0?0`(0(+_C#Q@`8`X8U6P3,8Q@D@`&DD_H`&"
M@5L`##N]`H2`?@``@3T`!("*``"`J0``2``964O__OB`?@``2``:?4O__I"!
M70`$/2`!@("]``A\9AMX@(H``#AI5=1,QC&"2``9^4@`&064(?_0/4`!@'P(
M`J:3X0`L/^`!@I/!`"@[_P$L?'X;>#B!`!@X:E/4D`$`-($_``"1(0`<.2``
M`$S&,8)+_^`=+`,``$&"`"R)(P``+`D``$&"`"`H"0`P08(`&"P>``!!@@`0
MB3X``"P)``!`@@`P@2$`'(%?``!]*5)Y.4```$""`)R``0`T@\$`*(/A`"Q\
M"`.F."$`,$Z``"!_P_-XDZ$`)$O_Z;$X@``O?'T;>$@`%X$L`P``08(`"#NC
M``%_H^MX2``:/3R``8`XA%2$.*``!$@`%STL`P``08(`#(.A`"1+__^,@2$`
M'(%?``!]*5)Y.4```$""`"B``0`T?\/S>(.A`"2#P0`H?`@#IH/A`"PX(0`P
M2__@6).A`"1(`!?AE"'^@'P(`J8X@P`<.*``0)/!`7@_P`&"D^$!?#O>`2Q\
M?QMX.&$`'($^``"1(0%<.2```)`!`82300%HDV$!;).!`7"3H0%T2``7=3D@
M`$`Y00`8?2D#IGU(4WB$Z@`$@2@`.(#(`"2!"``,?2DR>'TI0GA]*3IX52D(
M/I$J`$!"`/_8@)\`!($A`!R`?P`(5)OP/H#?``P]*5J"@4$`('QHVGB!?P``
M?'TR>("_`!`\ZEJ".2EYF8%!`"158"@^?[T@.'T(6#A]*2H4..=YF7^],GA\
MYS(4?2D"%'T(&GA58/`^?2GJ%'T(.A0_JEJ"@.$`*']J`GA5/"@^?4I(.#N]
M>9E5*?`^?0CB%'U*VGA_O1H4/X=:@GP'2GA]2NH4?.=`.(.A`"P[G'F951HH
M/G^<VA15"/`^?.<">'U*TA1]+$)X?.?B%#^]6H*#@0`P.[UYF7V,4#A56R@^
M?!T"%%5*\#Y]C$IX/YQ:@GSGVA1]'5)X?8P"%#@<>9F#@0`T5/LH/G^].#A4
MY_`^?8S:%'T@2A1_O4)X?4`Z>#^<6H)_O4H4.YQYF56)*#Y\`&`X?[U*%'T<
M0A2!(0`X?`!2>%6,\#Y\`$(45Z@H/GP`0A0_B5J"@0$`/'SI8GA]*>@X.YQY
MF5>]\#Y_G%(4/0A:@GTJ.GA]B>IX5!LH/GU*XA0Y"'F9@X$`0'TI`#A]2MH4
M5`#P/GSH.A1]*6)X?Z@">#]\6H)]*3H455PH/GTIXA0[>WF9@X$`1'T(4#A5
M1_`^?9MB%'T(ZGA\"CIX/WQ:@GT(8A15/"@^?4I(.'T(XA0[>WF9@X$`2%4I
M\#Y_>^H4?4H">'S]2G@_7%J"?4K:%%4<*#Y]2N(4?[U`.(.!`$P[6GF950CP
M/G]:`A1_O3IX?2!">#]\6H)_O=(455PH/GP`4#A_O>(4.WMYF8.!`%!52O`^
M?WLZ%'P`2GA]!U)X/UQ:@GP`VA17O"@^?`#B%'SGZ#B#@0!4.UIYF7]:2A1\
MZ4)X5[WP/C]\6H)]*=(45!PH/GTIXA1]1^IX@X$`6'SG`#@[>WF95`#P/G][
M0A1\YU)X?Z@">#]<6H)]"$@X53PH/GSGVA0[6GF9?.?B%']:4A2#@0!<?0KJ
M>%4I\#Y]2M(45.@H/GP,2GA]"D(4/WQ:@H%!`&!]C#@X.WMYF53G\#Y_>^H4
M/XI:@GV=`GB!00!D?2PZ>'^]VA1]C$`X51LH/CN<>9E5"/`^?[W:%'^<`A0]
M2EJ"?8!*>'SL0GA7NR@^?`#B%#E*>9F#@0!H?8SH.'P`VA17O?`^?2I*%'V,
M.GA]"NIX?8Q*%#^<6H)4"2@^?8Q*%'U*`#B!(0!L.YQYF7^<.A1]1T)X5`#P
M/CU);MI\Y^(459PH/GSGXA2!(0!P?[P">#E*ZZ%_G&)X?4I"%%6,\#X]"6[:
M?4KB%%3\*#Y]2N(4@2$`='P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\
MZ6[:?0CB%($A`'A]G.IX..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSG
MXA2!(0!\?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`
M@'P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`(1]G.IX
M..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!(0"(?[P">#E*ZZ%_
MG$)X?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`C'P<8G@Y".NA?YPZ>'T(
MZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`)!]G.IX..?KH7^<4GA\YP(4?.?B
M%%5`\#Y5'"@^/4ENVGSGXA2!(0"4?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^
M5/PH/CT);MI]2N(4@2$`F'P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\
MZ6[:?0CB%($A`)Q]G.IX..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSG
MXA2!(0"@?[P">#E*ZZ%_G$)X?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`
MI'P<8G@Y".NA?YPZ>'T(ZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`*A]G.IX
M..?KH7^<4GA\YP(4?.?B%%5`\#Y5'"@^/4ENVGSGXA2!(0"L?[P">#E*ZZ%_
MG$)X?4IB%'U*XA15#/`^5/PH/CT);MI]2N(4@2$`L'P<8G@Y".NA?YPZ>'T(
MZA1]".(45/WP/E5<*#X\Z6[:?0CB%($A`+1]G.IX..?KH7^<4GA\YP(4?.?B
M%%5`\#Y5'"@^/4ENVGSGXA2!(0"X?[P">#E*ZZ%_G$)X@V$`O'U*8A15"/`^
M?4KB%#TI;MI4_"@^?!I">'U*XA0Y*>NA5/SP/C][CQQ_1SIX?2GJ%#M[O-Q]
M'>-X?WL"%'TI.A1]`.`X54<H/G^]4#A]*3H4?[T#>(#A`,!52O`^53HH/G^]
MVA1_@%-X?[W2%#SGCQR#00#$?YM0.#CGO-Q\`$@X?0="%%4I\#Y\`-MX/WJ/
M''U'2WA\`$(4.WN\W%>H*#Y\`$(4?YOB%($!`,A]6T@X?.?H.%>]\#Y\Y]MX
M?2SK>%0;*#Y\Y^(4/0B/''SGVA1]/.@X@V$`S#D(O-Q]C``X?4A2%'V,XWA4
M`/`^/YN/''V,4A14ZB@^?8Q2%'^H`WB!00#0.YR\W'T\2A1]"#@X?[P`.%3G
M\#Y]".-X/VJ/'%6<*#Y\"CMX?0A*%#M[O-Q]".(4?WOJ%(.!`-1\'3@X?4I@
M.%6)\#Y]2NMX/9R/''U*VA15'"@^?4KB%'S]2WB#@0#8.8R\W'^]0#A]C`(4
M?.!(.%4(\#Y_H`-X/WR/''T]0WA57"@^?`!B%#M[O-Q\`.(4?[U0.(.!`-Q_
M>SH4?2=`.%5*\#Y_ISMX/9R/''SGVA14'"@^?.?B%'T=4WB#@0#@.8R\W'^]
M`#A]C$H4?0E0.%0`\#Y_J4MX/WR/''U=`WA4_"@^?2EB%#M[O-Q]*>(4?[TX
M.(.!`.1_>T(4?4@`.%3G\#Y_J$-X/9R/''T(VA15/"@^?0CB%'P=.WB#@0#H
M.8R\W'^]2#A]C%(4?`HX.%4I\#Y_JE-X/WR/''S]2WA5'"@^?4IB%#M[O-Q]
M2N(4?WL"%(.!`.Q\X$@X?[U`.%4(\#Y_O0-X/9R/''^]VA157"@^?[WB%'T@
M0WB#@0#P.8R\W'V,.A1\`%`X?2=`.%5*\#Y\`#MX/WR/''T'4WA7O"@^?`!B
M%#M[O-Q\`.(4?.?H.(.!`/1_>TH4?0E0.%>]\#Y\Z4MX/9R/''TIVA14'"@^
M?2GB%'U'ZWB#@0#X.8R\W'V,0A1\YP`X?4CH.%0`\#Y\YT-X/WR/''^H`WA5
M/"@^?.=B%#M[O-Q\Y^(4?WM2%(.!`/Q_J@`X?0A(.%4I\#Y]"%-X/9R/''T(
MVA14_"@^?0CB%'P*2WB#@0$`.8R\W'V,ZA1]2C@X?!U(.%3G\#Y]2NMX/YR/
M''T].WA5&R@^?4IB%#F<O-R#@0$$?4K:%'^]0#A].S@X50CP/GP,`A1_O=MX
M?.Q#>#^<CQQ56R@^?[T"%#N<O-Q50/`^?8Q0.(%!`0A]/$H4?/Q`.'^]VA1]
MC.-X/XJ/''V,2A1]"@-X5ZDH/CN<O-Q]C$H4?4KH.'^<.A2!(0$,?0<`.%>]
M\#Y]1SMX/4G*8WSGXA15G"@^?.?B%($A`1!\'.IX.4K!UG^<8GA]2D(458SP
M/CT)RF-]2N(45/PH/GU*XA2!(0$4?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^
M55PH/CSIRF-]".(4@2$!&'V<`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]
M2<IC?.?B%($A`1Q\'.IX.4K!UG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*
MXA2!(0$@?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!
M)'V<`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`2A\'.IX
M.4K!UG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*XA2!(0$L?[QB>#D(P=9_
MG#IX?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!,'V<`G@XY\'6?YQ2>'SG
MZA1\Y^(455WP/E4<*#X]2<IC?.?B%($A`31\'.IX.4K!UG^<0GA]2F(4?4KB
M%%4,\#Y4_"@^/0G*8WU*XA2!(0$X?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^
M55PH/CSIRF-]".(4@2$!/'V<`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]
M2<IC?.?B%($A`4!\'.IX.4K!UG^<0GA]2F(4?4KB%%4,\#Y4_"@^/0G*8WU*
MXA2!(0%$?[QB>#D(P=9_G#IX?0@"%'T(XA14X/`^55PH/CSIRF-]".(4@2$!
M2'V<`G@XY\'6?YQ2>'SGZA1\Y^(455WP/E4<*#X]2<IC@2$!3'SGXA0Y2L'6
M?!SJ>'^<0GA]2F(450SP/CT)RF.!(0%0?4KB%%3\*#XY",'6?4KB%#TIRF-_
MO&)X?0@"%'^<.G@Y*<'65.#P/GT(XA151R@^?2GJ%(.A`51]"#H4?9P">(#A
M`5A_G%)X/[W*8U5*\#Y]*>(451LH/GP<4G@[O<'6/.?*8WTIVA1_G$)X?[UB
M%%4(\#XXY\'6?[WB%'SG6A1]7$)X52LH/G^<2GA\YP(4?7U:%'SGXA158"@^
M?.<"%%4I\#Z0_P``?09"%'U%4A1\A%H4?2D:%(#A`5R`W@``?.<R>3C```"1
M7P`0D1\`#)"?``21/P`(0((`+(`!`82#00%H@V$!;'P(`Z:#@0%P@Z$!=(/!
M`7B#X0%\."$!@$Z``"!(``EQE"'_\'P(`J8X8`!@D`$`%$@`"^T\P._-/."8
MNCT`$#(]0,/2/(!G16#%JXE@A",!8.;<_F$'5'9A2.'P.4```)"#``"0HP`$
MD,,`")#C``R1`P`0D4,`%)%#`!B10P!<@`$`%#@A`!!\"`.F3H``()0A_]!\
M"`*F5*D8.%2H'WZ300`8?)HC>)-A`!R3@0`@?+PK>)/A`"Q\?QMXD`$`-#M_
M`!R3H0`D@4,`%(!C`%Q]*5(4@/\`&'U*2!`L`P``?4I1$)$_`!1]2CA0?0A2
M%)$?`!A!@@!((2,`0'R]*WA\!4@`08$!*'Q[&A1_I>MX?T33>$@`"%F!/P!<
M?3U*%"P)`$"1/P!<0*(`X'_C^WA_G>!0?UKJ%$O_\'DL'``_0($`M#N<_\"3
M(0`45YG1OI,!`!`[&0`!D\$`*',)``%_7=-X?Q[#>$&"`"PXH`!`?T33>']C
MVW@[N@!`2``'\7_C^WA+__`M+!D``'\^RWA!@@!(?Z3K>#B@`$!_8]MX.[T`
M0$@`!\E_X_MX2__P!7^DZW@XH`!`?V/;>$@`![$[WO__?^/[>#N]`$!+_^_E
M-][__T""_\`?.?_`5Q@P,G]:PA2#P0`H?YGB%(,!`!"#(0`4?T33>']CVWA_
MA>-X2``';9.?`%R``0`T@T$`&(-A`!Q\"`.F@X$`((.A`"2#X0`L."$`,$Z`
M`"!]/4MX?'L:%'^EZWA_1--X2``',8$_`%Q]/4H4+`D`0)$_`%Q`@O^X2__^
MV)0A_]!\"`*F.4#_@).A`"0[I``<D\$`*'Q^&WB3X0`L?)\C>)`!`#2380`<
MDX$`((.$`!2#9``85XGNOCBI``%]74FN+`4`.'Q]*A1`@0$4(*4`0#B```!(
M``==?^/[>$O_[OE_H^MX.*``.#B```!(``=%DW\`5'_C^WB3GP!82__NV8D_
M``!_X_MXF3X``*$_``"9/@`!@3\``%4IPCZ9/@`"@3\``)D^``.)/P`$F3X`
M!*$_``29/@`%@3\`!%4IPCZ9/@`&@3\`!)D^``>)/P`(F3X`"*$_``B9/@`)
M@3\`"%4IPCZ9/@`*@3\`")D^``N)/P`,F3X`#*$_``R9/@`-@3\`#%4IPCZ9
M/@`.@3\`#)D^``^)/P`0F3X`$*$_`!"9/@`1@3\`$%4IPCZ9/@`2@3\`$)D^
M`!.``0`T@V$`'(.!`"!\"`.F@Z$`)(/!`"B#X0`L."$`,$@`!1@@I0`X.(``
M`$@`!DU+__\(E"'_X'P(`J9"GP`%D\$`&'_(`J8_W@`"D`$`)#O>->B!'H`$
MB2@`)"P)``!`@@"HDX$`$#C@``&!7H`4@YZ`&)CH`"1\"N!`0(``=#N<__^3
MX0`<?XK@4).A`!17G/"^.ZK__#O\``%SZ0`!08(`'($J``!]75-X?2D#IDZ`
M!"%_G^-Y08(`,($]``0[G0`$.____SN]``A]*0.F3H`$(8$\``1]*0.F3H`$
M(3?___]`@O_8@Z$`%(/A`!R!/H`<+`D``$&"`"2`?H`,2``&N8.!`!"``0`D
M@\$`&#@A`"!\"`.F3H``((`!`"2#@0`0@\$`&'P(`Z8X(0`@3H``()0A_^!\
M"`*F0I\`!9/!`!A_R`*F/]X``I`!`"0[WC3H@)Z`!(DD```L"0``0((`I($^
M@`@Y0``!DZ$`%"P)``"91```08(`$(!^@`PXA``$2``$A8.^@`"!/H`0?!U(
M0$"!`(23@0`0.YW__W^)X%"3X0`<5YSPOCO\``%SZ0`!08(`&(4]__Q]*0.F
M3H`$(7^?XWE!@@`P@3W__#N=__P[____.[W_^'TI`Z9.@`0A@3S__'TI`Z9.
M@`0A-____T""_]B#@0`0@Z$`%(/A`!R``0`D@\$`&#@A`"!\"`.F3H``((.A
M`!1+___HE"'_P'P(`J:3P0`X/\`!@I!A`!P[W@$LD($`&#AA`!R0H0`4.($`
M&#BA`!2!/@``D2$`+#D@``"0`0!$DZ$`-)/A`#Q(``1E/*`!@#Q@`8`XI4_0
M.&-0H'RD*W@_X`&"2``$F3T@`8*+J0$H.___]"P=``!!@@%X@Z$`'(/___Q_
M_Q(4/2!``(%?```X?0`$?`-(0#N]``.)*@/682D``YDJ`]9`@`&\5&,0.C_@
M`8)(``.Y@($`'(%!`!@](`&"+`0``8#I`1"`J@``/0`!@#T@`8`Y"%88.2E6
M'#O_`H20HP``?&8;>)$#``20XP`(D2,`#)!_``1`@0&`.23__SCD__YQ*``!
M.0,`#$""`,A5*?A^?2D#IH!J``0XZ@`$.2@`!#E*``B0:``$.0@`"(#G``20
MZ0`$0@#_X#DD``-5*1`Z.4```(!_``P\@`&`?49)+G^EZW@XA!P(..```$@`
M`_DL`P``08(`L(!_``Q(``)9.($`*'Q]&W@\8`&`.&-3R$S&,8)+_\FI+`,`
M`$&"`)2`?P`,2``!X4@``VV!(0`L@5X``'TI4GDY0```0((`V(`!`$1_H^MX
M@\$`.(.A`#1\"`.F@^$`/#@A`$!.@``@+`<``(3J``1\:!MXE.@`$$""_RQ+
M__]42``"'3U``8(L`P``D&H"D$&"`(1(``$Y@3___'TI$A2!*0``FZD&?DO_
M_F2`?P`,2``#S4O__TR`?P`(+`,``$&"``Q+_^BI2___8#Q@`8`X@0`H.&-3
M:$S&,8)+_\CI+`,``)!_``A!@O]`2__H@4O__S@\@`&"/&`!@#B$_I@X8U58
M3,8Q@D@``E4Y(``$2__^Q#A@``%(```52``!46````!@````8````#U@`8*!
M:P``?6D#IDZ`!"`]8`&"@6L`!'UI`Z9.@`0@/6`!@H%K``A]:0.F3H`$(#U@
M`8*!:P`,?6D#IDZ`!"`]8`&"@6L`$'UI`Z9.@`0@/6`!@H%K`!1]:0.F3H`$
M(#U@`8*!:P`8?6D#IDZ`!"`]8`&"@6L`''UI`Z9.@`0@/6`!@H%K`"!]:0.F
M3H`$(#U@`8*!:P`D?6D#IDZ`!"`]8`&"@6L`*'UI`Z9.@`0@/6`!@H%K`"Q]
M:0.F3H`$(#U@`8*!:P`P?6D#IDZ`!"`]8`&"@6L`-'UI`Z9.@`0@/6`!@H%K
M`#A]:0.F3H`$(#U@`8*!:P`\?6D#IDZ`!"`]8`&"@6L`0'UI`Z9.@`0@/6`!
M@H%K`$1]:0.F3H`$(#U@`8*!:P!(?6D#IDZ`!"`]8`&"@6L`3'UI`Z9.@`0@
M/6`!@H%K`%!]:0.F3H`$(#U@`8*!:P!4?6D#IDZ`!"`]8`&"@6L`6'UI`Z9.
M@`0@/6`!@H%K`%Q]:0.F3H`$(#U@`8*!:P!@?6D#IDZ`!"`]8`&"@6L`9'UI
M`Z9.@`0@/6`!@H%K`&A]:0.F3H`$(#U@`8*!:P!L?6D#IDZ`!"`]8`&"@6L`
M<'UI`Z9.@`0@/6`!@H%K`'1]:0.F3H`$(#U@`8*!:P!X?6D#IDZ`!"`]8`&"
M@6L`?'UI`Z9.@`0@/6`!@H%K`(!]:0.F3H`$(#U@`8*!:P"$?6D#IDZ`!"`]
M8`&"@6L`B'UI`Z9.@`0@/6`!@H%K`(Q]:0.F3H`$(#U@`8*!:P"0?6D#IDZ`
M!"`]8`&"@6L`E'UI`Z9.@`0@/6`!@H%K`)A]:0.F3H`$(#U@`8*!:P"<?6D#
MIDZ`!"`]8`&"@6L`H'UI`Z9.@`0@/6`!@H%K`*1]:0.F3H`$(#U@`8*!:P"H
M?6D#IDZ`!"`]8`&"@6L`K'UI`Z9.@`0@/6`!@H%K`+!]:0.F3H`$(#U@`8*!
M:P"T?6D#IDZ`!"`]8`&"@6L`N'UI`Z9.@`0@/6`!@H%K`+Q]:0.F3H`$(#U@
M`8*!:P#`?6D#IDZ`!"`]8`&"@6L`Q'UI`Z9.@`0@/6`!@H%K`,A]:0.F3H`$
M(#U@`8*!:P#,?6D#IDZ`!"`]8`&"@6L`T'UI`Z9.@`0@/6`!@H%K`-1]:0.F
M3H`$(#U@`8*!:P#8?6D#IDZ`!"`]8`&"@6L`W'UI`Z9.@`0@/6`!@H%K`.!]
M:0.F3H`$(#U@`8*!:P#D?6D#IDZ`!"`]8`&"@6L`Z'UI`Z9.@`0@/6`!@H%K
M`.Q]:0.F3H`$(#U@`8*!:P#P?6D#IDZ`!"`]8`&"@6L`]'UI`Z9.@`0@/6`!
M@H%K`/A]:0.F3H`$(#U@`8*!:P#\?6D#IDZ`!"!(``$`2```_$@``/A(``#T
M2```\$@``.Q(``#H2```Y$@``.!(``#<2```V$@``-1(``#02```S$@``,A(
M``#$2```P$@``+Q(``"X2```M$@``+!(``"L2```J$@``*1(``"@2```G$@`
M`)A(``"42```D$@``(Q(``"(2```A$@``(!(``!\2```>$@``'1(``!P2```
M;$@``&A(``!D2```8$@``%Q(``!82```5$@``%!(``!,2```2$@``$1(``!`
M2```/$@``#A(```T2```,$@``"Q(```H2```)&````!@````8````&````!@
M````8````&````!@````/8`!@CUK_H"`#/_X.6NN@'P)`Z9\"UH4@8S__'U@
M6A1.@`0@8````&````!@````8````&````!@````8````'P(`J:0`0`$E"'_
M\$O_]C$X(0`0@`$`!'P(`Z9.@``@<'-?<W1R:6YG<R!M:7-S:6YG"@`O=&UP
M+P```"X```!005)?5$U01$E2``!414U01$E2`%1-4`!54T52`````%5315).
M04U%`````"5S+R5S````1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`````%!!4E]414U0`````%!!4E]04D]'3D%-
M10`````Z````)7,E<R5S``!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'3$]"04Q?1$5"
M54<`````4$%27T=,3T)!3%]435!$25(```!005)?1TQ/0D%,7U1%35``4$%2
M7T=,3T)!3%]#3$5!3@`````Q````;'-E96L@9F%I;&5D`````')E860@9F%I
M;&5D`$Q$7TQ)0E)!4EE?4$%42`!365-414T``"4P,G@`````<&%R+0`````E
M<R5S)7,E<P`````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O
M<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@<')I=F%T92!S=6)D:7)E
M8W1O<GD@)7,@:7,@=6YS869E("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R
M>2!Y;W5R(&]P97)A=&EO;BD*``!0051(`````'!A<FP`````+G!A<@````!S
M:&]R="!R96%D```E<R5S8V%C:&4M)7,E<P``)7,E<W1E;7`M)74E<P```"5S
M)7-T96UP+25U+25U)7,`````&````'!E<FP`````,````%!!4CHZ4&%C:V5R
M.CI615)324].`````#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D
M:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@
M/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA
M;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(
M+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D
M;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U
M;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@
M=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*
M)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H
M)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@
M>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG
M="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M
M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N
M("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O
M+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D
M9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F
M:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO
M9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR
M97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I
M<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@
M/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.
M0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H
M)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64[
M"GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S
M:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[
M)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?34%'24,I('L*;W5T
M<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T:6]N(&EN(&9I;&4@
M(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T87)T7W!O<R`]("AT
M96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T87)T(&]F('II<`I]
M"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@)&-A
M8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI
M=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*:68@*"$D
M<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@
M<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@8FQI8E]T;U]P87(*
M:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R"G,@("!S:6=N7W!A
M<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD("1!4D=66S!=(&5Q
M("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM005)?05!07U)%55-%
M?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V
M:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6*2!["B1!4D=66S!=
M(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["FEF("@D
M,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#(["GT*96QS:68@*"0Q
M(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF("@D,2!E<2`G02<I
M('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF("@D,2!E<2`G3R<I
M('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I('L*)&)U;F1L92`]
M("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B=6YD;&4@/2`G86QL
M)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`](#$["GT*96QS:68@
M*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE('%Q
M6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]"F5L<VEF("@D,2!E
M<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF="A`05)'5BD["FEF
M("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE=&4@)$5.5GLG4$%2
M7U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z.D1I<W0["B9[(E!!
M4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF>R)005(Z.D1I<W0Z
M.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*=6YS:&EF="!`24Y#
M+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*<F5Q=6ER92!)3SHZ
M1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I<F4@1&EG97-T.CI3
M2$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@)'II<#L*:68@*&1E
M9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W)RP@)'!A<B!O<B!D
M:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z("0A73L*8FQE<W,H
M)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II
M<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R(#T@9&\@>PII9B`H
M)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT<R@G345402YY;6PG
M*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE=&$@/7X@<R]>7%,N
M*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*?0I].PII
M9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G/#IR87<G+"`D<&%R
M(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D<&%R(CH@)"%=.PIM
M>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q6R(D<&%R(B!I<R!N
M;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+6DE07TU!1TE#.PIC
M;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL
M93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R
M(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z("0A73L*)&9H+3YB
M:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R.PII9B`H9&5F
M:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E860@7T9(+"`D;&]A
M9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L<V4@>PIL;V-A;"`D
M+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@*"$D14Y6>U!!4E]6
M15)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H+3YP<FEN="@D;&]A
M9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D97(@=&\@(B1O=70B
M.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2
M.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U
M:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG
M<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[
M<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C
M:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D
M97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E
M>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@
M;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K
M97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF
M("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME
M>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92![
M"F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D
M:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*
M;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@
M>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D
M;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I
M('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*
M?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I
M='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@
M/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN
M9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@
M)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT
M96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F
M.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T
M(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD=&@^.PIC;&]S92`D
M=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B
M/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD
M("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M
M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA
M;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O
M;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T
M:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*;W5T<RAQ<5M7<FET
M=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2!["B1Z:7`M/G=R:71E
M5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2PIO<B!D
M:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B)&]U=")=.PI]"FEF
M("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H(EPP0TQ%04XB*3L*
M?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE*2!["FUY("1C='@@
M/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@,"P@,#L*)&-T>"T^
M861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A8VAE7VYA;64@/2`D
M8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE
M7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H95]N86UE("X](")<
M,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D8V%C:&5?;F%M92D[
M"B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%(BD["GT*;7D@)&]F
M9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*3L*)&9H+3YP<FEN
M="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I.PHD9F@M/F-L;W-E
M(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@;V8@(B1O=70B.B`D
M(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D
M969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!0
M05(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E
M($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]
M($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C
M($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^
M9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F
M86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(
M*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH)'II<"T^<F5A9$9R
M;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z
M.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E
M("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H-C0@
M*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II<#L*)%!!4CHZ3&EB
M0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X=')A8W1I;F<@>FEP
M+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD
M(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D
M>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y
M.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC`````8!2]`&`4OP`````
M`8!3``&`4P0!@%,,`8!3;`&`4Q0``````8!3&`&`4R```````$-!0TA%```!
M&P,[````^````![__W\(```!$/__?\0```%$__^`4````83__X)$```"5/__
M@UP```+`__^%$````S3__X6T```#8/__B#0```.\__^(K````^3__XCD```#
M_/__B/0```04__^,````!*#__XQ````$R/__CA@```50__^3]```!9#__Y2$
M```%N/__E2````74__^7!```!AC__Y<T```&./__F&P```:,__^?A```!SC_
M_Z'L```'</__HQ````?L__^Q@```""C__['P```(2/__L[@```B0__^U*```
M`@S__[8H```!R/__MQ0```>\__^YK````;0````0``````%Z4@`$?$$!&PP!
M`````#`````8__]]\````+P`00X@00E!`$*>`D:<!!%!?T6?`4*=`U?=0=]$
M!D%!WMP.```````\````3/__?G@```",`$$.($$)00!"G@)%G`2?`40107]"
MG0-,W40&04+?WMP.`$$.()P$G0.>`I\!$4%_````+````(S__W[$```!]`!!
M#B!!"4$`0IL%0IX"1)H&$4%_0IP$09T#09\!````````$````+S__[?P```%
M0`````````!`````T/__M%@```#L`$$.($$)00!"G@)'$4%_1)T#2YP$0Y\!
M5=Q!W4'?0]X.`$$&04$.()T#G@(107]!W0```````$0```$4__^S%````0``
M00X@00E!`$*>`D<107]"G`1(GP%"G0-7W4'?1MQ#W@X`009!00X@G`2>`A%!
M?T+<0@9!0=X.`````&@```%<__]_Z````1@`00XP09P$0I\!0YL%1)H&0IT#
M3@E!`$&>`D$107]/VD';009!0=U!WD3?W`X`00XPF@:;!9P$G0.>`I\!$4%_
M1MK;W=X&04*;!4';0IH&FP6=`T/:0=M!W0```````'````'(__^`E````;0`
M00[0`4&=`T*?`5$*W]T.`$$+00E!`$&>`D$107]$F@9"G`11FP5<VTD*VD'<
M009!0=Y!"T?:W$+>009!09H&FP6<!)X"$4%_0MK;W-X&04$)00!!F@9!$4%_
M09L%09P$09X"````*````CS__X'4````I`!!#L`!0@E!`)\!2)X"$4%_6PH&
M04'?W@X`00L```!8```":/__@DP```*``$$.4$4107^;!9P$G0-$G@*?`4N9
M!YH&`D$*!D%&W][=W-O:V0X`00M+EPE!F`AB"M=!V$$+2-?80I<)F`A#U]A!
MEPE!F`A"UT'8`````"0```+$__^$<````'@`00X@1`E!`)\!0Q%!?U0&04'?
M#@`````````4```"[/__A,`````X`$(.$$L.```````4```#!/__A.`````0
M`$$.$$(.``````"(```#'/__A-@```,,`$$.\`E$"4$`EPE$G`2?`4H107^;
M!05&#%4*"48,0@9!0@9&0]_<V]<.`$$+09H&2I4+0I8*0I@(0ID'0IX"0IT#
M`DX*U4'60=A!V4':0=U!WD$+6-5!UD'80=E!VD'=0=Y!F@9!VD*5"T&6"D&8
M"$&9!T&:!D&=`T&>`@```"0```.H__^'6````$``00X@0PE!`)\!0A%!?TC?
M#@!!!D$```````"$```#T/__AW````'8`$$.L`A!G0-"G@)*"4$`09\!01%!
M?T:<!&?<1]]"!D%"WMT.`$$.L`B=`YX"2M[=#@!!#K`(G`2=`YX"GP$107]*
MW$*<!$C<0M]!!D%#WMT.`$$.L`B=`YX"GP$107]!G`1!W-\&04$)00!!G`1!
M$4%_09\!````````/```!%C__XC````%W`!!#D!""4$`GP%#G@)+$4%_F0>:
M!IL%G`2=`P,!4PH&047?WMW<V]K9#@!""P```````"0```28__^.7````)``
M00XP1`E!`)\!1!%!?U8*WPX`009!00L````8```$P/__CL0```"<`$$.@`%$
M$4%_````````0```!-S__X]$```!Y`!%#M"`!$4)00"7"9H&39L%G0,107^8
M")D'G`2>`I\!`D4*!D%(W][=W-O:V=C7#@!!"P`````<```%(/__D.0````P
M`$$.$$(107]'#@!!!D$``````%````5`__^0]````3@`00Y`0@E!`)X"0YT#
M0YP$2)\!$4%_4@H&04/?WMW<#@!""T*;!5C;0P9!1-_>W=P.`$(.0)P$G0.>
M`I\!$4%_09L%`````*@```64__^1V```!Q@`0@[0`DL)00"<!$*=`U*;!4J?
M`1%!?TB8"$&9!T&:!D&>`@)W"MA!V4$&04':0=Y%W]W<VPX`00M/E@I"EPE#
MUD'7;]C9VMY+!D%#W]W<VPX`00[0`I@(F0>:!IL%G`2=`YX"GP$107]'E@J7
M"0)>"M9!UT$+`DO6UT&6"D&7"4'6U]C9VMY!E@I!EPE!F`A!F0=!F@9!G@(`
M```````T```&0/__F$0```)H`$$.0$,)00"?`4B<!!%!?YL%G0-"G@("90H&
M043?WMW<VPX`00L``````$@```9X__^:=````20`00XP0PE!`)\!0YX"1Q%!
M?U<*!D%!W]X.`$$+0IT#4`K=00M(W4(&04+?W@X`00XPG@*?`1%!?T&=`P``
M```L```&Q/__KU````*,`$$.0$()00">`DX107^=`Y\!`F$*!D%"W][=#@!!
M"P`````X```&]/__FQP```YP`$$.@`-$"4$`G@)#GP%*$4%_F@:;!9P$G0,#
M`X,*!D%%W][=W-O:#@!!"P`````<```',/__J5````!P`$$.$$,107]6#@!!
M!D$``````$0```=0__^IH````<@`00XP1`E!`)H&0YL%G`1"GP%/$4%_G0-6
MF0="F`A"G@)CWD+80=E)"@9!1-_=W-O:#@!!"P```````#0```>8__^K(```
M`7``00XP0PE!`)T#0IX"0I\!1!%!?YL%G`0"1PH&043?WMW<VPX`00L`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````````#_____
M`````/____\``````````````````````````````````````8(!#`&!_H0!
M@?Z$`8`/B`&`#X@!@%+@`8(!&`&"`2`!@@$,`8("6`&!_Q`!@?Z$`8'^A`&`
M$MP!@?Z$`8'^A`&`4L`!@?Z(`8("7``````!@)6<`8'^B`&!_I`!@?Z0````
M``````$````!`````0```EL````!```"90````$```)Z`````0```L<````/
M```$0P````P!@!*@````#0&`4L`````$`8`!>`````4!@`K`````!@&`!)``
M```*```$BP````L````0````%0`````````#`8(```````(```,`````%```
M``<````7`8`/H'`````!@?_T````!P&`#TP````(```#5`````D````,````
M````````````````````````````````````````````````````````````
M``````&!_Q````````````&`48`!@%&$`8!1B`&`48P!@%&0`8!1E`&`49@!
M@%&<`8!1H`&`4:0!@%&H`8!1K`&`4;`!@%&T`8!1N`&`4;P!@%'``8!1Q`&`
M4<@!@%',`8!1T`&`4=0!@%'8`8!1W`&`4>`!@%'D`8!1Z`&`4>P!@%'P`8!1
M]`&`4?@!@%'\`8!2``&`4@0!@%((`8!2#`&`4A`!@%(4`8!2&`&`4AP!@%(@
M`8!2)`&`4B@!@%(L`8!2,`&`4C0!@%(X`8!2/`&`4D`!@%)$`8!22`&`4DP!
M@%)0`8!25`&`4E@!@%)<`8!28`&`4F0!@%)H`8!2;`&`4G`!@%)T`8!2>`&`
M4GP*4$%2+G!M"@`````!@@)8`8!6($=#0SH@*$YE=$)31"!N8C(@,C`R,S`W
M,3`I(#$P+C4N,`!'0T,Z("AN8C(@,C`R,S`W,3`I(#$P+C4N,``D3F5T0E-$
M.B!C<G0P+E,L=B`Q+C<@,C`Q."\Q,2\R-B`Q-SHS-SHT-2!J;V5R9R!%>'`@
M)``D3F5T0E-$.B!C<G0P+6-O;6UO;BYC+'8@,2XR-R`R,#(R+S`V+S(Q(#`V
M.C4R.C$W('-K<FQL($5X<"`D`"1.971"4T0Z(&-R=&DN4RQV(#$N-"`R,#$T
M+S`S+S`V(#$Y.C`U.C4Y(&UA='0@17AP("0`)$YE=$)31#H@8W)T8F5G:6XN
M8RQV(#$N,3<@,C`Q."\Q,B\R."`Q.#HQ-SHQ,2!C:')I<W1O<R!%>'`@)``D
M3F5T0E-$.B!C<G1E;F0N4RQV(#$N,R`R,#$T+S`R+S(W(#$V.C0W.C0X(&UA
M='0@17AP("0`)$YE=$)31#H@8W)T;BY3+'8@,2XR(#(P,30O,#(O,C<@,38Z
M-#<Z-#@@;6%T="!%>'`@)`!!````#V=N=0`!````!P0)`"YS:'-T<G1A8@`N
M:6YT97)P`"YN;W1E+FYE=&)S9"YI9&5N=``N;F]T92YN971B<V0N<&%X`"YH
M87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L82YD>6X`+G)E;&$N<&QT`"YI;FET
M`"YT97AT`"YF:6YI`"YR;V1A=&$`+F5H7V9R86UE7VAD<@`N96A?9G)A;64`
M+F-T;W)S`"YD=&]R<P`N:F-R`"YD871A+G)E;"YR;P`N9FEX=7``+F=O=#(`
M+F1Y;F%M:6,`+F=O=``N9&%T80`N<V1A=&$`+G-B<W,`+F)S<P`N8V]M;65N
M=``N9VYU+F%T=')I8G5T97,`````````````````````````````````````
M```````````````````````+`````0````(!@`$T```!-````!<`````````
M``````$`````````$P````<````"`8`!3````4P````8```````````````$
M`````````"8````'`````@&``60```%D````%```````````````!```````
M```W````!0````(!@`%X```!>````Q@````%``````````0````$````/0``
M``L````"`8`$D```!)````8P````!@````$````$````$````$4````#````
M`@&`"L````K````$BP```````````````0````````!-````!`````(!@`],
M```/3````%0````%``````````0````,````5P````0```!"`8`/H```#Z``
M``,`````!0```!<````$````#````&$````!````!@&`$J```!*@````(```
M````````````!`````````!G`````0````8!@!+````2P```0```````````
M`````!``````````;0````$````&`8!2P```4L`````@```````````````$
M`````````',````!`````@&`4N```%+@``!`\P``````````````!```````
M``![`````0````(!@)/4``"3U````/P```````````````0`````````B0``
M``$````"`8"4T```E-````?0```````````````$`````````),````!````
M`P&!_H0``/Z$````"```````````````!`````````":`````0````,!@?Z,
M``#^C`````@```````````````0`````````H0````$````#`8'^E```_I0`
M```$```````````````$`````````*8````!`````P&!_I@``/Z8````$P``
M````````````!`````````"S`````0````,!@?ZL``#^K`````0`````````
M``````0`````````N@````$````#`8'^L```_K````!@```````````````$
M`````````,`````&`````P&!_Q```/\0````X`````8`````````!`````@`
M``#)`````0````,!@?_P``#_\````!````````````````0````$````7```
M``$````#`8(````!``````$````````````````$`````````,X````!````
M`P&"`0```0$`````"0``````````````!`````````#4`````0````,!@@$,
M``$!#`````@```````````````0`````````VP````@````#`8(!&``!`10`
M```0```````````````(`````````.$````(`````P&"`2@``0$4```!;```
M````````````"`````````#F`````0```#````````$!%````#T`````````
M``````$````!````'P````$````P```````!`5$```%3```````````````!
M`````0```.]O___U`````````````0*D````$````````````````0``````
G```!`````P````````````$"M````/\```````````````$`````
